//-----------------------------------------------------------------------------
// Written by Philippe.CASTAGLIOLA@univ-nantes.fr
// Université de Nantes & IRCCyN UMR CNRS 6597
//-----------------------------------------------------------------------------
function [inter,sigma]=intnormals(X,side,level)
//intnormals – normal confidence interval for σ
//
//Syntax
//  [inter,sigma] = intnormals(X, side=, level=)
//
//Parameters
//    – X : real matrix X containing normal data.
//    – side : side of the confidence interval. Must be "lower", "upper" or "both". Default is "both".
//    – level : confidence level 1 − α ∈ (0.5, 1). Default is 0.95.
//    – inter : normal confidence interval for σ:
//    – if side="lower", inter is the lower confidence bound.
//    – if side="upper", inter is the upper confidence bound.
//    – if side="both", inter is the bilateral confidence interval.
//    – sigma : estimation of parameter σ of the normal distribution.
//
//Description
//    Compute the confidence interval (lower, upper or both) for the parameter σ of the normal distribution.
//    [inter,sigma]=intnormals(X) is equivalent to [inter,sigma]=intnormals(X,"both",0.95).
//
//Examples
//    X = rndnormal(100, sigma=0.5);
//    [inter,sigma] = intnormals(X)
//    [inter,sigma] = intnormals(X, "upper")
//    [inter,sigma] = intnormals(X, level=0.99)
//
//See Also
//    tstnormals1

    //-----------------------------------------------------------------------------
    [argout,argin]=argn()
    if (argin<1)|(argin>3)
        error("incorrect number of arguments")
    end
    if ~exists("side","local")
        side="both"
    end
    if ~exists("level","local")
        level=0.95
    end
    if (level<=0.5)|(level>=1)
        error("argument ''level'' must be in (0.5,1)")
    end
    alpha=1-level
    n=size(X,"*")
    sigma=standev(X)
    select side
    case "lower"
        inter=sigma*sqrt((n-1)/idfchi2(1-alpha,n-1))
    case "upper"
        inter=sigma*sqrt((n-1)/idfchi2(alpha,n-1))
    case "both"
        inter(1)=sigma*sqrt((n-1)/idfchi2(1-alpha/2,n-1))
        inter(2)=sigma*sqrt((n-1)/idfchi2(alpha/2,n-1))
    else
        error("argument ''side'' must be ''lower'', ''upper'' or ''both''")
    end
endfunction
